pub struct KeccakNode(pub [u8; 32]);Expand description
Custom Keccak256 node for our merkle tree
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl AsRef<[u8]> for KeccakNode
impl AsRef<[u8]> for KeccakNode
Sourceimpl CanonicalDeserialize for KeccakNode
impl CanonicalDeserialize for KeccakNode
Sourcefn deserialize_with_mode<R: Read>(
reader: R,
_compress: Compress,
_validate: Validate,
) -> Result<Self, SerializationError>
fn deserialize_with_mode<R: Read>( reader: R, _compress: Compress, _validate: Validate, ) -> Result<Self, SerializationError>
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Sourceimpl CanonicalSerialize for KeccakNode
impl CanonicalSerialize for KeccakNode
Sourcefn serialize_with_mode<W: Write>(
&self,
writer: W,
_compress: Compress,
) -> Result<(), SerializationError>
fn serialize_with_mode<W: Write>( &self, writer: W, _compress: Compress, ) -> Result<(), SerializationError>
fn serialized_size(&self, _compress: Compress) -> usize
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn compressed_size(&self) -> usize
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn uncompressed_size(&self) -> usize
Sourceimpl Clone for KeccakNode
impl Clone for KeccakNode
Sourcefn clone(&self) -> KeccakNode
fn clone(&self) -> KeccakNode
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for KeccakNode
impl Debug for KeccakNode
Sourceimpl Default for KeccakNode
impl Default for KeccakNode
Sourcefn default() -> KeccakNode
fn default() -> KeccakNode
Sourceimpl DigestAlgorithm<KeccakNode, OuterIndex, KeccakNode> for OuterKeccak256Hasher
impl DigestAlgorithm<KeccakNode, OuterIndex, KeccakNode> for OuterKeccak256Hasher
Sourcefn digest(data: &[KeccakNode]) -> Result<KeccakNode, MerkleTreeError>
fn digest(data: &[KeccakNode]) -> Result<KeccakNode, MerkleTreeError>
Sourcefn digest_leaf(
_pos: &OuterIndex,
elem: &KeccakNode,
) -> Result<KeccakNode, MerkleTreeError>
fn digest_leaf( _pos: &OuterIndex, elem: &KeccakNode, ) -> Result<KeccakNode, MerkleTreeError>
Pass-through for leaf nodes (inner tree roots are already hashed).
Unlike typical Merkle trees where leaves are hashed, the outer tree’s “leaves” are inner tree roots that are already Keccak256 hashes. Hashing them again would add an unnecessary layer and break Solidity verification compatibility.
Arguments
_pos- Outer index (0-15), unusedelem- Inner tree root hash (already a Keccak256 digest)
Returns
The input hash unchanged
Sourceimpl DigestAlgorithm<RewardAmount, RewardAccountV2, KeccakNode> for Keccak256Hasher
impl DigestAlgorithm<RewardAmount, RewardAccountV2, KeccakNode> for Keccak256Hasher
Sourcefn digest(data: &[KeccakNode]) -> Result<KeccakNode, MerkleTreeError>
fn digest(data: &[KeccakNode]) -> Result<KeccakNode, MerkleTreeError>
Sourcefn digest_leaf(
_pos: &RewardAccountV2,
elem: &RewardAmount,
) -> Result<KeccakNode, MerkleTreeError>
fn digest_leaf( _pos: &RewardAccountV2, elem: &RewardAmount, ) -> Result<KeccakNode, MerkleTreeError>
Sourceimpl From<KeccakNode> for B256
impl From<KeccakNode> for B256
Sourcefn from(val: KeccakNode) -> Self
fn from(val: KeccakNode) -> Self
Sourceimpl Hash for KeccakNode
impl Hash for KeccakNode
Sourceimpl Ord for KeccakNode
impl Ord for KeccakNode
Sourcefn cmp(&self, other: &KeccakNode) -> Ordering
fn cmp(&self, other: &KeccakNode) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for KeccakNode
impl PartialEq for KeccakNode
Sourceimpl PartialOrd for KeccakNode
impl PartialOrd for KeccakNode
Sourceimpl Valid for KeccakNode
impl Valid for KeccakNode
impl Copy for KeccakNode
impl Eq for KeccakNode
impl StructuralPartialEq for KeccakNode